package rekisteri;

/***
 * Lasku luokka.
 * @author jimis
 * @version 29.3.2025
 *
 */
public class Lasku {

    private String sahkoposti = "";
    private String nimi = "";
    private boolean maksettu;
    private double hinta;
    private final int[] erapaiva = new int[] {1,1,2025};
    private final int[][] kuukausienMitat = {{31,28,31,30,31,30,31,31,30,31,30,31},{31,29,31,30,31,30,31,31,30,31,30,31}};
    /**
     * Tyhjä muodostaja
     */
    public Lasku()
    {        
    }
    
    /**
     * Lasku-olion muodostaja.
     * @param nimi laskutettavan nimi
     * @param sahkoposti laskutettavan sähkopostiosoite.
     * @param hinta ostosten hinta
     * @param maksettu onko lasku maksettu
     * @param paiva eräpäivän päivä-osa
     * @param kk eräpäivän kuukausiosa
     * @param v eräpäivän vuosiosa.
     */
    public Lasku(String nimi, String sahkoposti, double hinta, boolean maksettu, int paiva, int kk, int v)
    {
        this.nimi = nimi;
        this.sahkoposti = sahkoposti;
        this.hinta = hinta;
        this.maksettu = maksettu;
        if(tarkistaPvm(paiva,kk,v) == true)
        {
            this.erapaiva[0] = paiva;
            this.erapaiva[1] = kk;
            this.erapaiva[2] = v;
        }
        else
        {
            System.out.println("Syötä kelvollinen päivämäärä.");
        }
        return;
    }
        
    /**
     * Tarkistaa päivämäärän oikeellisuuden
     * @param paiva päivä
     * @param kuukausi kuukausi
     * @param vuosi vuosi
     * @return totuusarvon päivämäärän olemassaolosta
     */
    public boolean tarkistaPvm(int paiva, int kuukausi, int vuosi)
    {
        int karkausvuosi = 0;
        if((paiva <= 0)||(kuukausi <= 0)||(vuosi <= 2025 )) return false;
        if(kuukausi > 13) return false;
        if(kuukausi % 4 == 0) karkausvuosi = 1;
        if(paiva > kuukausienMitat[karkausvuosi][kuukausi-1]) return false;
        return true;
    }
    /**
     * Haetaan Teoksen nimi
     * @return Teoksen nimi
     */
    public boolean Getmaksettu()
    {
        return maksettu;
    }
    
    /**
     * Haetaan eräpäivää
     * @return eräpäivä muodossa XX.XX.20XX
     */
    public String GetErapaiva()
    {
        return erapaiva.toString();
    }
    
    /**
     * Haetaan hinta
     * @return hinta
     */
    public double getHinta()
    {
        return hinta;
    }
    
    /**
     * Haetaan maksajan nimi
     * @return nimi
     */
    public String getNimi()
    {
        return nimi;
    }
 
    /**
     * Palautetaan laskuun liitetty sähköposti.
     * @return Sähköposti
     */
    public String getSahkoposti()
    {
        return sahkoposti;
    }
    /**
     * Muokataan lasku-olion nimeä
     * @param uusiNimi uusi Nimi
     */
    public void setNimi(String uusiNimi)
    {
        nimi = uusiNimi;
    }
    
    /**
     * Muokataan lasku-olion hintaa
     * @param uusiHinta uusi hinta
     */
    public void setHinta(String uusiHinta)
    {
        StringBuilder hintateksti =new StringBuilder(uusiHinta);
        for(int i = 0; i<uusiHinta.length(); i++)
        {
            if(uusiHinta.charAt(i) == ',')
            {
                hintateksti.setCharAt(i, '.');
            }
        }
        double uusiHintaDbl = Double.parseDouble(hintateksti.toString()); 
        if(uusiHintaDbl > 0)
        {
            hinta = uusiHintaDbl;  
        }   
    }
    
    /**
     * Muokataan kirja-olion kirjailijaa
     * @param uusiSahkoposti uusi kirjialija.
     */
    public void setSahkoposti(String uusiSahkoposti)
    {
        if(uusiSahkoposti.contains("@")) sahkoposti = uusiSahkoposti;       
    }
    
    /**
     * Merkitään lasku maksetuksi
     */
    public void asetaMaksetuksi()
    {
        this.maksettu = true; 
    }
    
    /**
     * Pääohjelma
     * @param args ei käytössä
     */
    public static void main(String[] args)
    {
     Lasku lasku = new Lasku();
     lasku.setNimi("Pahani Julmu");
     System.out.println(lasku.getNimi());
     lasku.setHinta("13.25");
    }
    
    
}
